from distutils.core import setup

setup(
    name='jlj', #对外模块的名字
    version='1.0', #版本号
    description='第一个对外的模块，测试', #描述
    author='jiaodengjie', #作者
    author_email='1005563662@qq.com', #作者邮箱
    py_modules=['jlj.jie1','jlj.jie2'] #发布的模块
)